#!/usr/bin/env python
"""
Public domain.

Authors:
 Legoktm, 2013
"""

import os
import requests
import sys


def connect(dbname):
    if sys.version[0] == '3':
        raise NotImplementedError
    if dbname.endswith('_p'):
        dbname = dbname[:-2]
    import oursql
    return oursql.connect(db=dbname + '_p',
                          host=dbname + ".labsdb",
                          read_default_file=os.path.expanduser("~/replica.my.cnf"),
                          charset=None,
                          use_unicode=False,
                          )

def dbname(domain):
    # Function to figure out the dbname.
    # TODO: Cache these results

    # First, lets normalize the name.
    if domain.startswith(('http://', 'https://')):
        domain = domain.replace('http://', '', 1).replace('https://', '', 1)
    if '/' in domain:
        domain = domain.split('/', 1)[0]

    domain = 'http://' + domain  # May need to change when goes HTTPS-only
    params = {'action': 'sitematrix', 'format': 'json'}
    headers = {'User-agent': 'https://wikitech.wikimedia.org/wiki/User:Legoktm/wmflib'}
    r = requests.get('https://meta.wikimedia.org/w/api.php', params=params, headers=headers)
    data = r.json()['sitematrix']
    for num in data:
        if num.isdigit():
            for site in data[num]['site']:
                if site['url'] == domain:
                    return site['dbname']
        elif num == 'specials':
            for special in data[num]:
                if special['url'] == domain:
                    return special['dbname']



#!/usr/bin/env python
"""
Public domain.

Authors:
 Legoktm, 2013
"""

import os
import pipes
import re
import subprocess

environ = dict(os.environ)
environ['PATH'] = '/bin:/usr/bin:/usr/local/bin'

re_job = re.compile(' (?P<id>\d*?) (?P<prior>\d\.\d*?) (?P<name>.*?)\s*?(?P<user>.*?) (?P<state>.*?)\s*?(?P<date>\d\d/\d\d/\d\d\d\d \d\d:\d\d:\d\d) (?P<queue>.*?)\s*?')


def submit(command, **kwargs):
    """
    Example:
     submit('python script.py', N='script', mem='500M')
    """
    cmd = '/usr/local/bin/jsub '
    for kw in kwargs:
        cmd += '-{0} {1} '.format(kw, pipes.quote(kwargs[kw]))
    cmd += command
    output = subprocess.check_output(cmd,
                                     stderr=subprocess.STDOUT,
                                     shell=True,
                                     env=environ,
                                     )
    return output.split(' ')[2]


def qstat():
    """
    Returns a machine readable output of qstat
    """
    data = []
    output = subprocess.check_output('qstat')
    if not output:
        # No jobs running
        return data
    lines = output.splitlines()[2:]
    for line in lines:
        match = re_job.search(line)
        if match:
            data.append(match.groupdict())
    return data



from setuptools import setup
import sys

depends = ['requests']
if sys.version[0] == '2':
    depends.append('oursql')

setup(
    name='wmflabs',
    version='2.1',
    packages=['wmflabs'],
    url='https://wikitech.wikimedia.org/wiki/User:Legoktm/wmflib',
    license='Public domain',
    author='Kunal Mehta',
    author_email='legoktm@gmail.com',
    description='Small library for common tasks on Wikimedia Labs',
    install_requires=depends,
    test_suite="tests",
)
